@@ -63,15 +63,17 @@ tidyfeed <- function(feed, sf = TRUE){
   } else if(grepl("http://www.georss.org/georss", xml2::xml_attr(doc, "xmlns:georss"))){
 
     result <- geo_parse(doc)
-
-    if(sf == TRUE){
-      result <- sf::st_as_sf(x = result,
-                             coords = c("item_long", "item_lat"),
-                             crs = "+proj=longlat +datum=WGS84")
+    if(!exists('result$item_long')) {
+      result <- rss_parse(doc)
+      return(result)
+    } else{
+      if(sf == TRUE){
+        result <- sf::st_as_sf(x = result,
+                               coords = c("item_long", "item_lat"),
+                               crs = "+proj=longlat +datum=WGS84")
       }
-
-    return(result)
-
+      return(result)
+    }
   } else{
     result <- rss_parse(doc)
 
